import{d as g,e as k,t as v,i as s,c as n,j as i,k as r,o as a,l,n as t,cB as y,A as N,y as x,cC as C,cD as B,F as h,a as w}from"./index-BvWlZEEM.js";import{u as P}from"./usePageTitle-CKKzQl14.js";const F=g({__name:"Notifications",setup(V){const u=k(),e=v(u.notifications.getNotifications),c=s(()=>e.response??[]),f=s(()=>e.executed&&c.value.length===0),p=s(()=>e.executed);return P("Notifications"),(b,o)=>{const d=r("p-message"),m=r("p-layout-default");return a(),n(m,{class:"notifications"},{header:i(()=>[l(t(y))]),default:i(()=>[l(d,{info:""},{default:i(()=>[N(" Notifications are deprecated and will be migrated in the future. Please use Automations. ")]),_:1}),p.value?(a(),x(h,{key:0},[f.value?(a(),n(t(C),{key:0})):(a(),n(t(B),{key:1,notifications:c.value,onDelete:o[0]||(o[0]=_=>t(e).refresh()),onUpdate:o[1]||(o[1]=_=>t(e).refresh())},null,8,["notifications"]))],64)):w("",!0)]),_:1})}}});export{F as default};
//# sourceMappingURL=Notifications-p7RXZehv.js.map
