import{d as v,i as h,o as i,y as u,l as e,j as t,F as C,z as x,n,db as w,v as f,M as B,c as M,k as l,K as P,dc as V,dd as d,a6 as j}from"./index-BvWlZEEM.js";import{u as A}from"./usePageTitle-CKKzQl14.js";import{u as F}from"./usePrefectApi-BlB8Fus3.js";const K={class:"settings-block"},O=v({__name:"SettingsCodeBlock",props:{engineSettings:{}},setup(p){const s=p,a=h(()=>Object.entries(s.engineSettings));return(g,c)=>(i(),u("div",K,[e(n(w),{multiline:""},{default:t(()=>[(i(!0),u(C,null,x(a.value,(o,r)=>(i(),u("div",{key:r,class:"settings-block--code-line"},f(o[0])+": "+f(o[1]),1))),128))]),_:1})]))}}),I=v({__name:"Settings",async setup(p){let s,a;const g=[{text:"Settings"}],c=F(),[o,r]=([s,a]=B(()=>Promise.all([c.admin.getSettings(),c.admin.getVersion()])),s=await s,a(),s);return A("Settings"),(T,m)=>{const b=l("p-key-value"),S=l("p-theme-toggle"),_=l("p-label"),k=l("p-layout-default");return i(),M(k,{class:"settings"},{header:t(()=>[e(n(P),{crumbs:g},{actions:t(()=>[e(b,{class:"settings__version",label:"Version",value:n(r),alternate:""},null,8,["value"])]),_:1})]),default:t(()=>[e(_,{label:"Theme"},{default:t(()=>[e(S)]),_:1}),e(_,{label:"Color Mode",class:"settings__color-mode"},{default:t(()=>[e(n(V),{selected:n(d),"onUpdate:selected":m[0]||(m[0]=y=>j(d)?d.value=y:null)},null,8,["selected"])]),_:1}),e(_,{label:"Server Settings"},{default:t(()=>[e(O,{class:"settings__code-block","engine-settings":n(o)},null,8,["engine-settings"])]),_:1})]),_:1})}}});export{I as default};
//# sourceMappingURL=Settings-CdWU9CNh.js.map
