import{d as f,e as i,t as _,i as o,c as s,j as n,k as w,o as t,l as k,n as a,bR as y,y as C,bS as b,bT as F,F as h,a as v}from"./index-BvWlZEEM.js";import{u as x}from"./usePageTitle-CKKzQl14.js";const S=f({__name:"Flows",setup(g){const l=i(),c={interval:3e4},e=_(l.flows.getFlowsCount,[{}],c),r=o(()=>e.response??0),u=o(()=>e.executed&&r.value===0),p=o(()=>e.executed),m=()=>{e.refresh()};return x("Flows"),(B,D)=>{const d=w("p-layout-default");return t(),s(d,{class:"flows"},{header:n(()=>[k(a(y))]),default:n(()=>[p.value?(t(),C(h,{key:0},[u.value?(t(),s(a(b),{key:0})):(t(),s(a(F),{key:1,selectable:"",onDelete:m}))],64)):v("",!0)]),_:1})}}});export{S as default};
//# sourceMappingURL=Flows-bzXDele4.js.map
