import{d as l,e as p,c as _,j as o,k as m,o as d,l as e,n,cE as C,cF as h,cc as c,bo as i,N}from"./index-BvWlZEEM.js";import{u as w}from"./usePageTitle-CKKzQl14.js";const x=l({__name:"NotificationCreate",setup(y){const r=p();async function s(t){try{await r.notifications.createNotification(t),c.push(i.notifications())}catch(a){N("Error creating notification","error"),console.warn(a)}}function u(){c.push(i.notifications())}return w("Create Notification"),(t,a)=>{const f=m("p-layout-default");return d(),_(f,{class:"notification-create"},{header:o(()=>[e(n(C))]),default:o(()=>[e(n(h),{action:"Create",onSubmit:s,onCancel:u})]),_:1})}}});export{x as default};
//# sourceMappingURL=NotificationCreate-BJfjMt3p.js.map
