import{d as s,c as r,j as a,k as c,o as n,l as e,n as t,aT as _,aU as f}from"./index-BvWlZEEM.js";import{u as l}from"./usePageTitle-CKKzQl14.js";const h=s({__name:"Artifacts",setup(p){return l("Artifacts"),(u,i)=>{const o=c("p-layout-default");return n(),r(o,{class:"artifacts"},{header:a(()=>[e(t(_))]),default:a(()=>[e(t(f))]),_:1})}}});export{h as default};
//# sourceMappingURL=Artifacts-DlxznA8C.js.map
