import{d as I,e as P,W as R,t as S,i as p,af as T,ao as V,c,j as e,k as n,G as _,aK as W,o as l,n as t,aL as $,a as i,aM as d,y as h,l as s,aN as D,aO as Q,aP as v,A as j,v as E,aQ as m,a6 as F}from"./index-BvWlZEEM.js";import{u as G}from"./usePageTitle-CKKzQl14.js";const H={key:0},U=I({__name:"Artifact",setup(K){const y=P(),b=R("artifactId"),k=S(y.artifacts.getArtifact,[b]),a=p(()=>k.response),o=T(!1),w=[{label:"Artifact"},{label:"Details"},{label:"Raw"}],u=V("tab","Artifact"),x=p(()=>a.value?`${_.info.artifact}: ${a.value.key??W(a.value.type)}`:_.info.artifact);return G(x),(L,r)=>{const A=n("p-divider"),C=n("p-button"),g=n("p-content"),N=n("p-tabs"),B=n("p-layout-well");return l(),c(B,{class:"artifact"},{header:e(()=>[a.value?(l(),c(t($),{key:0,artifact:a.value},null,8,["artifact"])):i("",!0)]),well:e(()=>[a.value?(l(),c(t(d),{key:0,artifact:a.value,alternate:""},null,8,["artifact"])):i("",!0)]),default:e(()=>[a.value?(l(),h("section",H,[s(t(D),{artifact:a.value},null,8,["artifact"]),s(A),t(Q).xl?(l(),c(g,{key:0},{default:e(()=>[s(t(v),{artifact:a.value},null,8,["artifact"]),s(C,{class:"artifact__raw-data-button",small:"",onClick:r[0]||(r[0]=f=>o.value=!o.value)},{default:e(()=>[j(E(o.value?"Hide":"Show")+" raw data ",1)]),_:1}),o.value?(l(),c(t(m),{key:0,artifact:a.value},null,8,["artifact"])):i("",!0)]),_:1})):(l(),c(N,{key:1,selected:t(u),"onUpdate:selected":r[1]||(r[1]=f=>F(u)?u.value=f:null),tabs:w},{artifact:e(()=>[s(t(v),{artifact:a.value},null,8,["artifact"])]),details:e(()=>[s(t(d),{artifact:a.value},null,8,["artifact"])]),raw:e(()=>[s(t(m),{artifact:a.value},null,8,["artifact"])]),_:1},8,["selected"]))])):i("",!0)]),_:1})}}});export{U as default};
//# sourceMappingURL=Artifact-CL0p-NWh.js.map
