import{d,af as m,e as _,i as o,G as v,c as r,j as c,k as b,t as k,o as s,l as y,n,cR as h,y as x,cS as C,cT as V,F as g,a as B}from"./index-BvWlZEEM.js";import{u as E}from"./usePageTitle-CKKzQl14.js";const N=d({__name:"Variables",setup(S){const l=m(),a=()=>{var e;t.value.refresh(),(e=l.value)==null||e.refreshSubscriptions()},u=_(),t=o(()=>k(u.variables.getVariables)),i=o(()=>{var e;return t.value.executed&&((e=t.value.response)==null?void 0:e.length)===0}),p=o(()=>t.value.executed);return E(v.info.variables),(e,w)=>{const f=b("p-layout-default");return s(),r(f,{class:"variables"},{header:c(()=>[y(n(h),{onCreate:a})]),default:c(()=>[p.value?(s(),x(g,{key:0},[i.value?(s(),r(n(C),{key:0,onCreate:a})):(s(),r(n(V),{key:1,ref_key:"table",ref:l,onDelete:a,onUpdate:a},null,512))],64)):B("",!0)]),_:1})}}});export{N as default};
//# sourceMappingURL=Variables-Cy0nMFf4.js.map
