import{d as i,e as b,W as d,i as o,bK as _,c as f,j as c,a as v,k as D,g as B,o as g,l as n,n as s,cx as h,cy as w,bo as x}from"./index-BvWlZEEM.js";import{u as y}from"./usePageTitle-CKKzQl14.js";const S=i({__name:"BlockView",setup(C){const u=b(),l=B(),t=d("blockDocumentId"),a=o(()=>t.value?[t.value]:null),r=_(u.blockDocuments.getBlockDocument,a),e=o(()=>r.response),m=()=>{l.push(x.blocks())},k=o(()=>e.value?`Block: ${e.value.name}`:"Block");return y(k),(V,I)=>{const p=D("p-layout-default");return e.value?(g(),f(p,{key:0,class:"block-view"},{header:c(()=>[n(s(h),{"block-document":e.value,onDelete:m},null,8,["block-document"])]),default:c(()=>[n(s(w),{"block-document":e.value},null,8,["block-document"])]),_:1})):v("",!0)}}});export{S as default};
//# sourceMappingURL=BlockView-BBUWp_PR.js.map
