import{d as k,e as y,W as i,i as o,bK as b,c as m,j as a,a as _,k as d,o as f,l as t,n as c,cq as T,cr as v}from"./index-BvWlZEEM.js";import{u as g}from"./usePageTitle-CKKzQl14.js";const x=k({__name:"BlocksCatalogView",setup(B){const s=y(),l=i("blockTypeSlug"),n=o(()=>l.value?[l.value]:null),u=b(s.blockTypes.getBlockTypeBySlug,n),e=o(()=>u.response),r=o(()=>e.value?`Block Type: ${e.value.name}`:null);return g(r),(C,S)=>{const p=d("p-layout-default");return e.value?(f(),m(p,{key:0,class:"blocks-catalog-view"},{header:a(()=>[t(c(T),{"block-type":e.value},null,8,["block-type"])]),default:a(()=>[t(c(v),{"block-type":e.value},null,8,["block-type"])]),_:1})):_("",!0)}}});export{x as default};
//# sourceMappingURL=BlocksCatalogView-JG7vMeam.js.map
