import{d as m,e as p,t as d,i as a,c as s,j as c,k,o as t,l as _,n as o,ck as f,y as i,cl as y,cm as B,F as x,a as C}from"./index-BvWlZEEM.js";import{u as h}from"./usePageTitle-CKKzQl14.js";const F=m({__name:"Blocks",setup(D){const n=p(),e=d(n.blockDocuments.getBlockDocumentsCount),l=a(()=>e.executed&&e.response==0),r=a(()=>e.executed);return h("Blocks"),(b,g)=>{const u=k("p-layout-default");return t(),s(u,{class:"blocks"},{header:c(()=>[_(o(f))]),default:c(()=>[r.value?(t(),i(x,{key:0},[l.value?(t(),s(o(y),{key:0})):(t(),s(o(B),{key:1,onDelete:o(e).refresh},null,8,["onDelete"]))],64)):C("",!0)]),_:1})}}});export{F as default};
//# sourceMappingURL=Blocks-h53Iq2np.js.map
