import{d as c,e as _,W as u,M as k,c as m,j as l,k as w,o as d,l as r,n as e,d2 as i,d3 as f}from"./index-BvWlZEEM.js";import{u as P}from"./usePageTitle-CKKzQl14.js";const N=c({__name:"WorkPoolEdit",async setup(y){let o,a;const s=_(),n=u("workPoolName"),t=([o,a]=k(()=>s.workPools.getWorkPoolByName(n.value)),o=await o,a(),o);return P("Create Work Pool"),(C,W)=>{const p=w("p-layout-default");return d(),m(p,null,{header:l(()=>[r(e(i),{"work-pool":e(t)},null,8,["work-pool"])]),default:l(()=>[r(e(f),{"work-pool":e(t)},null,8,["work-pool"])]),_:1})}}});export{N as default};
//# sourceMappingURL=WorkPoolEdit-CwW-juwD.js.map
