import{d,e as i,t as y,i as o,c as a,j as n,k as _,o as t,l as f,n as s,b_ as k,y as b,b$ as h,bZ as v,F as x,a as D}from"./index-BvWlZEEM.js";import{u as g}from"./usePageTitle-CKKzQl14.js";const P=d({__name:"Deployments",setup(C){const l=i(),c={interval:3e4},e=y(l.deployments.getDeployments,[{}],c),p=o(()=>e.response??[]),r=o(()=>e.executed&&p.value.length===0),m=o(()=>e.executed);return g("Deployments"),(B,w)=>{const u=_("p-layout-default");return t(),a(u,{class:"deployments"},{header:n(()=>[f(s(k))]),default:n(()=>[m.value?(t(),b(x,{key:0},[r.value?(t(),a(s(h),{key:0})):(t(),a(s(v),{key:1,onDelete:s(e).refresh},null,8,["onDelete"]))],64)):D("",!0)]),_:1})}}});export{P as default};
//# sourceMappingURL=Deployments-B_fy7Grd.js.map
