import{d as f,e as x,f as b,W as c,i as r,aG as y,M as C,n as e,c as I,j as n,a as h,k,aH as w,o as A,l as s,aI as E,K as D,aJ as W}from"./index-BvWlZEEM.js";import{u as g}from"./usePageTitle-CKKzQl14.js";const N=f({__name:"Event",async setup(j){let a,o;const l=x(),u=b(),v=c("eventDate"),_=c("eventId"),m=r(()=>w(v.value)),d=y({startDate:m,eventId:[_.value]}),t=([a,o]=C(()=>l.events.getFirstEvent(d.value)),a=await a,o(),a),p=r(()=>[{text:"Event Feed",to:u.events()},{text:t.eventLabel}]);return g(`Event: ${t.eventLabel}`),(B,F)=>{const i=k("p-layout-default");return e(t)?(A(),I(i,{key:0,class:"event"},{header:n(()=>[s(e(D),{crumbs:p.value},{actions:n(()=>[s(e(E),{event:e(t)},null,8,["event"])]),_:1},8,["crumbs"])]),default:n(()=>[s(e(W),{event:e(t)},null,8,["event"])]),_:1})):h("",!0)}}});export{N as default};
//# sourceMappingURL=Event-C6vzT4Wu.js.map
