import{d as k,e as f,af as y,i as o,cn as m,t as _,c as d,j as s,k as v,o as C,l as t,n as l,co as g,cp as B}from"./index-BvWlZEEM.js";import{u as T}from"./usePageTitle-CKKzQl14.js";const S=k({__name:"BlocksCatalog",setup(x){const c=f(),a=y(null),p=o(()=>a.value?[a.value]:[]),{filter:n}=m({blockSchemas:{blockCapabilities:p}}),i=_(c.blockTypes.getBlockTypes,[n]),u=o(()=>i.response??[]);return T("Blocks Catalog"),(h,e)=>{const r=v("p-layout-default");return C(),d(r,{class:"blocks-catalog"},{header:s(()=>[t(l(g))]),default:s(()=>[t(l(B),{capability:a.value,"onUpdate:capability":e[0]||(e[0]=b=>a.value=b),"block-types":u.value},null,8,["capability","block-types"])]),_:1})}}});export{S as default};
//# sourceMappingURL=BlocksCatalog-D5ZAiOfI.js.map
