import{d as m,e as i,t as k,i as s,c as a,j as n,k as _,o,l as f,n as t,cZ as P,y,c_ as w,c$ as h,F as v,a as x}from"./index-BvWlZEEM.js";import{u as g}from"./usePageTitle-CKKzQl14.js";const F=m({__name:"WorkPools",setup(C){const r=i(),c={interval:3e4},e=k(r.workPools.getWorkPools,[{}],c),l=s(()=>e.response??[]),p=s(()=>e.executed&&l.value.length==0),u=s(()=>e.executed);return g("Work Pools"),(B,W)=>{const d=_("p-layout-default");return o(),a(d,{class:"work-pools"},{header:n(()=>[f(t(P))]),default:n(()=>[u.value?(o(),y(v,{key:0},[p.value?(o(),a(t(w),{key:0})):(o(),a(t(h),{key:1,onUpdate:t(e).refresh},null,8,["onUpdate"]))],64)):x("",!0)]),_:1})}}});export{F as default};
//# sourceMappingURL=WorkPools-zjRfwD73.js.map
