import{d as x,e as g,W as h,i as l,ao as D,bx as I,t as O,c,j as n,k as u,g as R,aO as S,o as a,n as t,cJ as T,a as r,cK as m,l as B,cL as J,a6 as N,bo as P}from"./index-BvWlZEEM.js";import{u as V}from"./usePageTitle-CKKzQl14.js";const K=x({__name:"ConcurrencyLimit",setup(W){const y=g(),p=h("concurrencyLimitId"),d=R(),v=l(()=>[{label:"Details",hidden:S.xl},{label:"Active Task Runs"}]),s=D("tab","Details"),{tabs:b}=I(v,s),_={interval:3e5},L=O(y.concurrencyLimits.getConcurrencyLimit,[p.value],_),e=l(()=>L.response);function f(){d.push(P.concurrencyLimits())}const k=l(()=>e.value?`Concurrency Limit: ${e.value.tag}`:"Concurrency Limit");return V(k),(j,i)=>{const C=u("p-tabs"),w=u("p-layout-well");return a(),c(w,{class:"concurrencyLimit"},{header:n(()=>[e.value?(a(),c(t(T),{key:0,"concurrency-limit":e.value,onDelete:f},null,8,["concurrency-limit"])):r("",!0)]),well:n(()=>[e.value?(a(),c(t(m),{key:0,alternate:"","concurrency-limit":e.value},null,8,["concurrency-limit"])):r("",!0)]),default:n(()=>[B(C,{selected:t(s),"onUpdate:selected":i[0]||(i[0]=o=>N(s)?s.value=o:null),tabs:t(b)},{details:n(()=>[e.value?(a(),c(t(m),{key:0,"concurrency-limit":e.value},null,8,["concurrency-limit"])):r("",!0)]),"active-task-runs":n(()=>{var o;return[(o=e.value)!=null&&o.activeSlots?(a(),c(t(J),{key:0,"active-slots":e.value.activeSlots},null,8,["active-slots"])):r("",!0)]}),_:1},8,["selected","tabs"])]),_:1})}}});export{K as default};
//# sourceMappingURL=ConcurrencyLimit-CgGepbp6.js.map
