import{d as r,W as n,c as s,j as a,k as u,o as p,l as t,n as o,d7 as m,d8 as c}from"./index-BvWlZEEM.js";import{u as _}from"./usePageTitle-CKKzQl14.js";const P=r({__name:"WorkPoolQueueCreate",setup(k){const e=n("workPoolName");return _("Create Work Pool Queue"),(d,f)=>{const l=u("p-layout-default");return p(),s(l,null,{header:a(()=>[t(o(m),{"work-pool-name":o(e)},null,8,["work-pool-name"])]),default:a(()=>[t(o(c),{"work-pool-name":o(e)},null,8,["work-pool-name"])]),_:1})}}});export{P as default};
//# sourceMappingURL=WorkPoolQueueCreate-N2Md2Ae2.js.map
