import{d as w,cM as d,ao as C,c as M,j as a,k as u,o as y,l,n as o,K as r,cN as h,a6 as i,cO as x,cP as R,cQ as v}from"./index-BvWlZEEM.js";const K=w({__name:"ConcurrencyLimits",setup(G){const{showModal:t,open:b}=d(),{showModal:e,open:m}=d(),_=[{label:"Global"},{label:"Task Run"}],c=C("tab","Global");return(g,s)=>{const p=u("p-button"),k=u("p-tabs"),f=u("p-layout-default");return y(),M(f,{class:"concurrency-limits"},{header:a(()=>[l(o(r),{crumbs:[{text:"Concurrency"}]})]),default:a(()=>[l(k,{selected:o(c),"onUpdate:selected":s[2]||(s[2]=n=>i(c)?c.value=n:null),tabs:_},{global:a(()=>[l(o(r),{size:"lg",crumbs:[{text:"Global Concurrency Limits"}]},{"after-crumbs":a(()=>[l(p,{small:"",icon:"PlusIcon",onClick:o(b)},null,8,["onClick"])]),_:1}),l(o(h),{showModal:o(t),"onUpdate:showModal":s[0]||(s[0]=n=>i(t)?t.value=n:null)},null,8,["showModal"]),l(o(x),{class:"concurrency-limits__global-table"})]),"task-run":a(()=>[l(o(r),{size:"lg",crumbs:[{text:"Task Run Concurrency Limits"}]},{"after-crumbs":a(()=>[l(p,{small:"",icon:"PlusIcon",onClick:o(m)},null,8,["onClick"])]),_:1}),l(o(R),{showModal:o(e),"onUpdate:showModal":s[1]||(s[1]=n=>i(e)?e.value=n:null)},null,8,["showModal"]),l(o(v),{class:"concurrency-limits__task-limits-table"})]),_:1},8,["selected"])]),_:1})}}});export{K as default};
//# sourceMappingURL=ConcurrencyLimits-DMHf_IPJ.js.map
