import{d as y,e as m,W as k,t as _,i as o,c as e,j as s,k as v,G as n,o as t,n as c,aR as d,a as r,aN as C,y as g,aS as B,F as h}from"./index-BvWlZEEM.js";import{u as x}from"./usePageTitle-CKKzQl14.js";const P=y({__name:"ArtifactKey",setup(F){const u=m(),i=k("artifactKey"),l=_(u.artifacts.getArtifactCollection,[i]),a=o(()=>l.response),f=o(()=>a.value?`${n.info.artifact}: ${a.value.key}`:n.info.artifact);return x(f),(K,w)=>{const p=v("p-layout-default");return t(),e(p,{class:"artifact"},{header:s(()=>[a.value?(t(),e(c(d),{key:0,artifact:a.value},null,8,["artifact"])):r("",!0)]),default:s(()=>[a.value?(t(),e(c(C),{key:0,artifact:a.value},null,8,["artifact"])):r("",!0),a.value?(t(),g(h,{key:1},[a.value.key?(t(),e(c(B),{key:0,"artifact-key":a.value.key},null,8,["artifact-key"])):r("",!0)],64)):r("",!0)]),_:1})}}});export{P as default};
//# sourceMappingURL=ArtifactKey-D75rJG57.js.map
